| Package: |
| PoisBinOrdNor |
| Type: |
| Package |
| Version: |
| 1.2 |
| Date: |
| 2016-05-18 |
| License: |
| GPL-2 | GPL-3 |
validation_specs validates the specificed quantities to avoid obvious specification errors.
The functions corr.nn4bb, corr.nn4bn, corr.nn4on, corr.nn4pbo, corr.nn4pn, and corr.nn4pp
each computes the intermediate correlation coefficient for binary-binary combinations, binary-normal combinations, ordinal-normal combinations, count-binary/ordinal combinations,
count-normal and count-count combinations, respectively.
The function intermat assembles the intermediate correlation matrix for the multivaraite data based on input from functions corr.nn4bb,
corr.nn4bn, corr.nn4on, corr.nn4pbo, corr.nn4pn and corr.nn4pp.
The engine function genPBONdata computes the final correlation matrix and generates mixed data in accordance with the specified marginal and correlational quantities.
Demirtas, H. & Hedeker, D. (2011). A practical way for computing approximate lower and upper correlation bounds. The American Statistician, 65(2), 104-109.
Demirtas, H. & Doganay, B. (2012). Simultaneous generation of binary and normal data with specified marginal and association structures. Journal of Biopharmaceutical Statistics, 22(2), 223-236.
Demirtas, H., Hedeker, D. & Mermelstein, R. J. (2012). Simulation of massive public health data by power polynomials. Statistics in Medicine, 31(27), 3337-3346.
Demirtas, H. & Yavuz, Y. (2015). Concurrent generation of ordinal and normal data. Journal of Biopharmaceutical Statistics, 25(4), 635-650.
Demirtas, H. & Hedeker, D. (2016). Computing the point-biserial correlation under any underlying continuous distribution. Forthcoming in Communications in Statistics--Simulation and Computation.
Ferrari, P.A. and Barberio, A. (2012). Simulating ordinal data. Multivariate Behavioral Research, 47(4), 566-589.
Yahav, I. & Shmueli, G. (2012). On generating multivariate Poisson data in management science applications. Applied Stochastic Models in Business and Industry, 28(1), 91-102.